@@ -179,8 +179,12 @@ def mpc_transfer(default_address, destination, chain_raw, token_raw, token_addre
         if chain_raw == 'base' and token_raw == 'usdc':
             transfer = default_address.transfer(amount, 'usdc', destination, gasless=True)
             transfer.wait()
-            transferred_wei = convert_to_wei(float(amount), chain_raw, token_raw)
-            if transfer.status is Transaction.Status.COMPLETE:
+            print(f"Transfer complete: {transfer}")
+            print(f"Transfer transfer.status: {transfer.status}")
+            print(f"Transaction.Status.COMPLETE: {Transaction.Status.COMPLETE}")
+            print(f"transfer.status is Transaction.Status.COMPLETE: {transfer.status is Transaction.Status.COMPLETE}")
+            print(f"transfer.status == Transaction.Status.COMPLETE: {transfer.status == Transaction.Status.COMPLETE}")
+            if str(transfer.status) == 'complete':
                 status = 200
                 transfer_status = 1
                 print(f"Transfer complete: {transfer.transaction_hash}")
@@ -190,7 +194,6 @@ def mpc_transfer(default_address, destination, chain_raw, token_raw, token_addre
                 # increase_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
                 status = 500
                 transfer_status = 0
-                transferred_wei = 0
                 print(f"Transfer failed on-chain: {transfer.transaction_link}")
 
             info = {
@@ -198,8 +201,7 @@ def mpc_transfer(default_address, destination, chain_raw, token_raw, token_addre
                 "tx_hash": transfer.transaction_hash,
                 "chain": chain_raw,
                 "status": transfer_status,
-                "code": status,
-                "transferred_wei": transferred_wei
+                "code": status
             }
 
             return info
@@ -249,8 +251,16 @@ def convert_to_value(amount, chain, token):
     amount = amount / (10 ** decimal)
     return float(amount)
 
+def get_token_address(chain, token):
+    try:
+        # Safely access nested keys using .get() to avoid KeyError
+        address = TOKEN_MAPPING.get(chain, {}).get(token, {}).get("address")
+        return address
+    except Exception as e:
+        return f"Get token address failed. Error: {str(e)}"
+
 def transfer(receiver: str, amount: float, step: any, chain: str = "base", token: str = "usdc", **kwargs: Any) -> Dict[str, Any]:
-    print(f"receiver: {receiver}, amount: {amount}, chain: {chain}, token: {token}, kwargs: {kwargs}, step: {step}")
+    print(f"receiver: {receiver}, amount: {amount}, chain: {chain}, token: {token}, step: {step}")
     
     chain_raw = chain.lower()
     executor = kwargs.get("executor")
@@ -271,7 +281,7 @@ def transfer(receiver: str, amount: float, step: any, chain: str = "base", token
     w3 = get_web3(providers, chain_raw)
     eth_w3 = get_web3(providers, 'eth')
     token_raw = token.lower()
-    token_address = TOKEN_MAPPING[chain_raw][token_raw]['address']
+    token_address = get_token_address(chain_raw, token_raw)
 
     mpc_address = kwargs.get('mpc_address')
     if token_address is not None:
@@ -301,7 +311,7 @@ def handle_auto_transfer(w3: Web3, eth_w3, mpc_address, executor, receiver, amou
         # print(f"allowance_normalized: {float(allowance_normalized)}")
         amount_to_transfer = convert_to_wei(float(amount), chain_raw, token_raw)
         try:
-            decrease_token_amount(redis_client, executor, chain_raw, token, amount_to_transfer)
+            decrease_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
         except Exception as e:
             print(f"Exception occurred: {e}", flush=True)
             return {'result': {"content": f"{e}", "code": 500}, 'action': None, 'next_action': None}
@@ -323,7 +333,7 @@ def handle_auto_transfer(w3: Web3, eth_w3, mpc_address, executor, receiver, amou
             info = mpc_transfer(mpc_address, to, chain_raw, token_raw, token_address, amount)
 
             if info['code'] != 200:
-                increase_token_amount(redis_client, executor, chain_raw, token, amount_to_transfer)
+                increase_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
 
             return {'result': info, 'action': None, 'next_action': None}
             # can_send, tx_hash = maybe_send_transaction(w3, control_contract, sender_address, token_address, executor, to, amount_to_transfer, private_key, chain_raw, executor_balance)
